<?php

namespace Icap\LessonBundle\Listener;

use Claroline\CoreBundle\Event\Log\CreateFormResourceEvent;
use Icap\NotificationBundle\Event\Notification\NotificationCreateDelegateViewEvent;
use JMS\DiExtraBundle\Annotation as DI;
use Symfony\Component\DependencyInjection\ContainerAware;

/**
 * Class NotificationListener
 * @package Icap\LessonBundle\Listener
 *
 * @DI\Service
 */
class NotificationListener
{
    private $templating;

    /**
     * @DI\InjectParams({
     *     "templating" = @DI\Inject("templating")
     * })
     */
    public function __construct($templating)
    {
        $this->templating = $templating;
    }

    /**
     * @param NotificationCreateDelegateViewEvent $event
     * @DI\Observe("create_notification_item_resource-icap_lesson-chapter_create")
     * @DI\Observe("create_notification_item_resource-icap_lesson-chapter_update")
     * @DI\Observe("create_notification_item_resource-icap_lesson-user_tagged")
     */
    public function onCreateNotificationItem(NotificationCreateDelegateViewEvent $event)
    {
        $notificationView = $event->getNotificationView();
        $notification = $notificationView->getNotification();
        $content = $this->templating->render(
            'IcapLessonBundle:Notification:notification_item.html.twig',
            array(
                'notification'  => $notification,
                'status'        => $notificationView->getStatus(),
                'systemName'    => $event->getSystemName()
            )
        );

        $event->setResponseContent($content);
        $event->stopPropagation();
    }
}