<?php

namespace UJM\ExoBundle\Repository;

use Doctrine\ORM\EntityRepository;

/**
 * ShareRepository
 *
 * This class was generated by the Doctrine ORM. Add your own custom
 * repository methods below.
 */
class ShareRepository extends EntityRepository
{
    /**
     * Allow to know if a question is shared with an user
     *
     * @access public
     *
     * @param integer $user id User
     * @param integer $question id Question
     *
     * Return array[Share]
     */
    public function getControlSharedQuestion($user, $question)
    {
        $qb = $this->createQueryBuilder('s');
        $qb->join('s.user', 'u')
            ->where($qb->expr()->in('s.question', $question))
            ->andWhere($qb->expr()->in('u.id', $user));

        return $qb->getQuery()->getResult();
    }

    /**
     * Get the shared questions in the import view of an exercise
     *
     * @access public
     *
     * @param integer $exoId id Exercise
     * @param integer $uid id User
     * @param Doectrine EntityManager $am
     *
     * Return array[Share]
     */
    public function getUserInteractionSharedImport($exoId, $uid, $em)
    {

        $questions = array();

        $dql = 'SELECT eq FROM UJM\ExoBundle\Entity\ExerciseQuestion eq WHERE eq.exercise= ?1
                ORDER BY eq.ordre';

        $query = $em->createQuery($dql)->setParameter(1, $exoId);
        $eqs = $query->getResult();

        foreach ($eqs as $eq) {
            $questions[] = $eq->getQuestion()->getId();
        }

        $qb = $this->createQueryBuilder('s');

        $qb->join('s.question', 'q')
           ->join('s.user', 'u')
           ->where($qb->expr()->in('u.id', $uid));
        if (count($questions) > 0) {
             $qb->andWhere('q.id not in ('.implode(',', $questions).')');
        }

        return $qb->getQuery()->getResult();
    }

    /**
     * Search shared questions by category
     *
     * @access public
     *
     * @param integer $userId id User
     * @param String $whatToFind string to find
     *
     * Return array[Share]
     */
    public function findByCategoryShared($userId, $whatToFind)
    {
        $dql = 'SELECT s FROM UJM\ExoBundle\Entity\Share s JOIN s.question q JOIN q.category c
            WHERE c.value LIKE ?1
            AND s.user = ?2';

        $query = $this->_em->createQuery($dql)
                      ->setParameters(array(1 => "%{$whatToFind}%", 2 => $userId));

        return $query->getResult();
    }

    /**
     * Search shared questions by title
     *
     * @access public
     *
     * @param integer $userId id User
     * @param String $whatToFind string to find
     *
     * Return array[Share]
     */
    public function findByTitleShared($userId, $whatToFind)
    {
        $dql = 'SELECT s FROM UJM\ExoBundle\Entity\Share s JOIN s.question q
            WHERE q.title LIKE ?1
            AND s.user = ?2';

        $query = $this->_em->createQuery($dql)
                      ->setParameters(array(1 => "%{$whatToFind}%", 2 => $userId));

        return $query->getResult();
    }

    /**
     * Search shared questions by type
     *
     * @access public
     *
     * @param integer $userId id User
     * @param String $whatToFind string to find
     *
     * Return array[Share]
     */
    public function findByTypeShared($userId, $whatToFind)
    {
        $dql = 'SELECT s FROM UJM\ExoBundle\Entity\Share s, UJM\ExoBundle\Entity\Interaction i
                WHERE s.question = i.question
                AND s.user = ?2
                AND i.type LIKE ?1';

        $query = $this->_em->createQuery($dql)
                      ->setParameters(array(1 => "%{$whatToFind}%", 2 => $userId));

        return $query->getResult();
    }

    /**
     * Search shared questions by contain
     *
     * @access public
     *
     * @param integer $userId id User
     * @param String $whatToFind string to find
     *
     * Return array[Share]
     */
    public function findByContainShared($userId, $whatToFind)
    {
         $dql = 'SELECT s FROM UJM\ExoBundle\Entity\Share s, UJM\ExoBundle\Entity\Interaction i
                WHERE s.question = i.question
                AND s.user = ?2
                AND i.invite LIKE ?1';

        $query = $this->_em->createQuery($dql)
                      ->setParameters(array(1 => "%{$whatToFind}%", 2 => $userId));

        return $query->getResult();
    }

    /**
     * Search shared questions
     *
     * @access public
     *
     * @param integer $userId id User
     * @param String $whatToFind string to find
     *
     * Return array[Share]
     */
    public function findByAllShared($userId, $whatToFind)
    {
        $dql = 'SELECT s FROM UJM\ExoBundle\Entity\Share s, UJM\ExoBundle\Entity\Interaction i,
                UJM\ExoBundle\Entity\Question q, UJM\ExoBundle\Entity\Category c
                WHERE s.question = i.question AND i.question = q AND q.category = c
                AND s.user = ?2
                AND (i.invite LIKE ?1 OR i.type LIKE ?1 OR c.value LIKE ?1 OR q.title LIKE ?1)
        ';

        $query = $this->_em->createQuery($dql)
                      ->setParameters(array(1 => "%{$whatToFind}%", 2 => $userId));

        return $query->getResult();
    }
}
