<?php

/**
* To import a Matching question in QTI
*
*/

namespace UJM\ExoBundle\Services\classes\QTI;

use UJM\ExoBundle\Entity\Proposal;
use UJM\ExoBundle\Entity\Label;
use UJM\ExoBundle\Entity\InteractionMatching;

class matchingImport extends qtiImport {

    protected $interactionMatching;
    protected $associatedLabels = [];

    /**
    * Implements the abstract method
    *
    * @access public
    *
    * @param qtiRepository $qtiRepos
    * @param DOMElement $assessmentItem assessmentItem of the question to imported
    */
    public function import(qtiRepository $qtiRepos, $assessmentItem) {
        $this->qtiRepos = $qtiRepos;
        $this->getQTICategory();
        $this->initAssessmentItem($assessmentItem);
        $this->createQuestion();
        $this->createInteraction();
        $this->interaction->setType('InteractionMatching');
        $this->om->persist($this->interaction);
        $this->om->flush();
        $this->createInteractionMatching();

        return $this->interactionMatching;
    }

    /**
    * Implements the abstract method
    *
    * @access protected
    *
    * @return $text
    */
    protected function getPrompt() {
        $prompt = '';
        $ib = $this->assessmentItem->getElementsByTagName("itemBody")->item(0);
        $ci = $ib->getElementsByTagName("matchInteraction")->item(0);
        $text = '';
        if ($ci->getElementsByTagName("prompt")->item(0)) {
            $prompt = $ci->getElementsByTagName("prompt")->item(0);
            $text = $this->domElementToString($prompt);
            $text = str_replace('<prompt>', '', $text);
            $text = str_replace('</prompt>', '', $text);
            $text = html_entity_decode($text);
        }
        return $text;
    }

    /**
    * Create the InteractionMatching object
    *
    * @access protected
    */
    protected function createInteractionMatching() {
        $this->interactionMatching = new InteractionMatching();
        $this->interactionMatching->setInteraction($this->interaction);
        //for recording the type of the question
        $this->matchingType();
        $this->getShuffle();
        $this->om->persist($this->interactionMatching);
        $this->om->flush();
        $this->createLabels();
        $this->createProposals();
    }

    /**
     * Get shuffle
     *
     * @access protected
     */
    protected function getShuffle() {
        $ib = $this->assessmentItem->getElementsByTagName("itemBody")->item(0);
        $mi = $ib->getElementsBYTagName("matchInteraction")->item(0);
        $shuffle = $mi->getAttribute("shuffle");
        if ($shuffle == 'true' ) {
            $this->interactionMatching->setShuffle(true);
        } else {
            $this->interactionMatching->setShuffle(false);
        }
        $this->om->persist($this->interactionMatching);
        $this->om->flush();
    }

    /**
     * Create Labels in BDD
     *
     * @access protected
     */
    protected function createLabels() {
        $ordre = 0;
        $ib = $this->assessmentItem->getElementsByTagName("itemBody")->item(0);
        $mi = $ib->getElementsByTagName("matchInteraction")->item(0);
        $sms = $mi->getElementsByTagName("simpleMatchSet")->item(1);

        foreach ($sms->getElementsByTagName("simpleAssociableChoice") as $simpleLabel) {
            //create a new Label and set attributes
            $label = new Label();
            $feedback = $simpleLabel->getElementsByTagName("feedbackInline");
            if ($feedback->item(0)) {
                $feedbackVal = $this->domElementToString($feedback->item(0));
                $feedbackVal = html_entity_decode($feedbackVal);
                $label->setFeedback($feedbackVal);
                $simpleLabel->removeChild($feedback->item(0));
            }
            $label->setValue($this->value($simpleLabel));
            $identifiant = $simpleLabel->getAttribute("identifier");
            $label->setScoreRightResponse($this->notation($identifiant));
            $label->setInteractionMatching($this->interactionMatching);
            $label->setOrdre($ordre);

           if ($simpleLabel->hasAttribute("fixed") && $simpleLabel->getAttribute("fixed") == 'true') {
                $label->setPositionForce(true);
            } else {
                $label->setPositionForce(false);
            }

            //recording in the DBB
            $this->om->persist($label);
            $this->associatedLabels[$identifiant] = $label;
            $ordre++;
        }
        $this->om->flush();
    }

    /**
     * Create Proposals in BDD
     *
     * @access protected
     */
    protected function createProposals() {
        $ordre = 0;
        $ib = $this->assessmentItem->getElementsByTagName("itemBody")->item(0);
        $mi = $ib->getElementsByTagName("matchInteraction")->item(0);
        $sms = $mi->getElementsByTagName("simpleMatchSet")->item(0);
        $labels = $this->associatedLabels;
        $allRelations = $this->relations();

        // foreach proposal into the export file
        foreach ($sms->getElementsByTagName("simpleAssociableChoice") as $simpleProposal) {
            $proposal = new Proposal();
            $proposal->setValue($this->value($simpleProposal));
            $proposal->setOrdre($ordre);

            if ($simpleProposal->hasAttribute("fixed") && $simpleProposal->getAttribute("fixed") == 'true') {
                $proposal->setPositionForce(true);
            } else {
                $proposal->setPositionForce(false);
            }

            $identifiant = $simpleProposal->getAttribute("identifier");
            $proposal->setInteractionMatching($this->interactionMatching);
            $this->om->persist($proposal);
            $rightLabels = [];
            $i=0;
            //compare all relations to the proposal selected
            foreach ($allRelations as $relation) {
                if (stripos($relation, $identifiant) !== false) {
                    $rightLabels[$i] = $relation;
                    $rightLabels[$i] = str_replace($identifiant, '', $rightLabels[$i]);
                    $rightLabels[$i] = str_replace(' ', '', $rightLabels[$i]);
                }
                $i++;
            }
            // foreach label of the export file, compare to the right relation
            foreach ($labels as $key => $label) {
                foreach ($rightLabels as $rightLabel) {
                    if ($key == $rightLabel) {
                        $proposal->addAssociatedLabel($label);
                        $proposal->setInteractionMatching($this->interactionMatching);
                        $this->om->persist($proposal);
                    }
                }
            }
            $ordre++;
        }
        $this->om->flush();
    }

    /**
     * get all relations of the question
     *
     * @access protected
     *
     * @return $allRelations
     */
    protected function relations() {
        $rd = $this->assessmentItem->getElementsByTagName("responseDeclaration")->item(0);
        $cr = $rd->getElementsByTagName("mapping")->item(0);
        $allRelations = [];

        foreach ($cr->getElementsByTagName("mapEntry") as $key => $relation) {
            $allRelations[$key] = $relation->getAttribute("mapKey");
        }
        return $allRelations;
    }

    /**
     * Get value of the balise
     *
     * @access protected
     *
     * @param type $balise
     *
     * @return $value
     */
    protected function value($balise) {
        $value = $this->domElementToString($balise);
        $value = preg_replace('(<simpleAssociableChoice.*?>)', '', $value);
        $value = str_replace('</simpleAssociableChoice>', '', $value);
        $value = html_entity_decode($value);

        return $value;
    }

    /**
     * Get the score of the relation
     *
     * @access protected
     *
     * @param type $identifiant
     *
     * @return $notation
     */
    protected function notation($identifiant) {
        $m = $this->assessmentItem->getElementsByTagName("mapping")->item(0);
        $notation = 0;
        foreach($m->getElementsByTagName("mapEntry") as $relation) {
            $value = $relation->getAttribute("mapKey");
            //if mapEntry match to identifier add the notation
            if (stripos($value, $identifiant)) {
                $notation = $notation + $relation->getAttribute("mappedValue");
            }
        }
        return $notation;
    }

    /**
    * Get Type Matching
    *
    * @access protected
    */
    protected function matchingType() {
        $ri = $this->assessmentItem->getElementsByTagName("responseDeclaration")->item(0);
        if ($ri->hasAttribute("cardinality") && $ri->getAttribute("cardinality") == 'single') {
            //type : to drag
            $type = $this->om
                         ->getRepository('UJMExoBundle:TypeMatching')
                         ->findOneBy(array('code' => 2));
            $this->interactionMatching->setTypeMatching($type);
        } else {
            //type : to bind
            $type = $this->om
                         ->getRepository('UJMExoBundle:TypeMatching')
                         ->findOneBy(array('code' => 1));
            $this->interactionMatching->setTypeMatching($type);
        }
    }

    /**
     * abstract method verify the qti
     *
     * @access protected
     *
     * @return boolean
     */
    protected function qtiIsValid()
    {

    }
}
